/**
 * @file
 * Author: Synapse-studio.
 */
(function ($) {
  'use strict';

  const YAPI = 'https://api-maps.yandex.ru/2.1/?lang=ru_RU';
  const W_H = window.innerHeight;
  var mapData;
  var mapCenterLat;
  var mapCenterLng;
  var init = false;

  $(document).ready(function () {
    prepareMap();
  });

  function prepareMap() {
    var pos = '<div class="ymap"><div id="synmap" style="min-height:500px"></div></div>';
    mapData = drupalSettings.synmapReplace ? drupalSettings.synmapReplace : drupalSettings.synmap;
    if (!$(mapData.map.attach).length) {
      return false;
    }
    mapCenterLat = mapData.map.offsetX ? parseFloat(mapData.map.latitude) + parseFloat(mapData.map.offsetX) : mapData.map.latitude;
    mapCenterLng = mapData.map.offsetY ? parseFloat(mapData.map.longitude) + parseFloat(mapData.map.offsetY) : mapData.map.longitude;
    $(mapData.map.attach).before(pos);
    loadMap();
  }

  function loadScript() {
    let script = document.createElement('script');
    script.onload = function() {
      ymaps.ready(ymapsInit);
    };
    script.src = YAPI;
    document.getElementsByTagName('body')[0].appendChild(script);
  }

  function loadMap() {
    let map = document.getElementById('synmap');
    window.addEventListener('scroll', function (e) {
      let condition = this.pageYOffset - (map.offsetTop - 2 * W_H);
      if (condition > 0 && !init) {
        loadScript();
        init = true;
      }
    });
  }

  function ymapsInit() {
    console.log('init');
    let map = new ymaps.Map('synmap', {
      center: [mapCenterLng, mapCenterLat],
      zoom: mapData.map.zoom,
      controls: ['zoomControl', 'fullscreenControl']
    });
    map.behaviors.disable('scrollZoom');
    // Point params.
    var faClass = 'fa-map-marker-alt',
      faShape = {
        type: 'Rectangle',
        coordinates: [
          [0, 40],
          [52, 110]
        ]
      },
      faOffset = [-22, -110],
      pointCounter = 0;
    var pointsCollection = new ymaps.GeoObjectCollection();
    $.each(mapData.data, function (index, POINT) {
      pointCounter++;
      var pointID = `point${pointCounter}`,
        pointLayout = {
          iconLayout: ymaps.templateLayoutFactory.createClass(`<i id="${pointID}" class="${pointID} fas ${faClass}">
                    <div><span>${POINT.name}</span></div>
                  </i>`),
          iconContent: 'Active',
          iconShape: faShape,
          iconOffset: faOffset,
        },
        Placemark = new ymaps.Placemark(
          [POINT.longitude, POINT.latitude], {}, pointLayout);
      Placemark.events.add('click', function () {
        $('#' + pointID).toggleClass('hover')
      }).add('mouseenter', function () {
        $('#' + pointID).addClass('hover')
      }).add('mouseleave', function () {
        $('#' + pointID).removeClass('hover')
      })
      pointsCollection.add(Placemark)
    });
    map.geoObjects.add(pointsCollection);

    // Center Position.
    if (mapData.map.centerAuto === true) {
      var bounds = map.geoObjects.getBounds();
      map.setBounds(bounds, {
        checkZoomRange: true
      }).then(function () {
        if (map.getZoom() > 16) {
          map.setZoom(16);
        }
      });
    }
    else {
      // Move center.
      var position = map.getGlobalPixelCenter();
      map.setGlobalPixelCenter([
        position[0] - mapData.map.centerAutoX,
        position[1] - mapData.map.centerAutoY
      ]);
    }
  }
})(this.jQuery);